aboutsummaryrefslogtreecommitdiffstats
path: root/core/vm/jump_table.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/vm/jump_table.go')
-rw-r--r--core/vm/jump_table.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/core/vm/jump_table.go b/core/vm/jump_table.go
index f0a922912..9ef192fdf 100644
--- a/core/vm/jump_table.go
+++ b/core/vm/jump_table.go
@@ -51,14 +51,14 @@ type operation struct {
}
var (
- frontierInstructionSet = NewFrontierInstructionSet()
- homesteadInstructionSet = NewHomesteadInstructionSet()
- metropolisInstructionSet = NewMetropolisInstructionSet()
+ frontierInstructionSet = NewFrontierInstructionSet()
+ homesteadInstructionSet = NewHomesteadInstructionSet()
+ byzantiumInstructionSet = NewByzantiumInstructionSet()
)
-// NewMetropolisInstructionSet returns the frontier, homestead and
-// metropolis instructions.
-func NewMetropolisInstructionSet() [256]operation {
+// NewByzantiumInstructionSet returns the frontier, homestead and
+// byzantium instructions.
+func NewByzantiumInstructionSet() [256]operation {
// instructions that can be executed during the homestead phase.
instructionSet := NewHomesteadInstructionSet()
instructionSet[STATICCALL] = operation{